from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.bulk_company_logos_body_companies_identifier_type_1 import BulkCompanyLogosBodyCompaniesIdentifierType1
  from ..models.bulk_company_logos_body_companies_identifier_type_2 import BulkCompanyLogosBodyCompaniesIdentifierType2
  from ..models.bulk_company_logos_body_companies_identifier_type_0 import BulkCompanyLogosBodyCompaniesIdentifierType0





T = TypeVar("T", bound="BulkCompanyLogosBody")



@_attrs_define
class BulkCompanyLogosBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            companies_identifier (Union['BulkCompanyLogosBodyCompaniesIdentifierType0',
                'BulkCompanyLogosBodyCompaniesIdentifierType1', 'BulkCompanyLogosBodyCompaniesIdentifierType2']): The list of
                companies to get the logo for. Include any of domain, linkedinUrl, or liOrgId. Max 10000 companies can be added
                at a time.
     """

    api_key: str
    companies_identifier: Union['BulkCompanyLogosBodyCompaniesIdentifierType0', 'BulkCompanyLogosBodyCompaniesIdentifierType1', 'BulkCompanyLogosBodyCompaniesIdentifierType2']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.bulk_company_logos_body_companies_identifier_type_1 import BulkCompanyLogosBodyCompaniesIdentifierType1
        from ..models.bulk_company_logos_body_companies_identifier_type_2 import BulkCompanyLogosBodyCompaniesIdentifierType2
        from ..models.bulk_company_logos_body_companies_identifier_type_0 import BulkCompanyLogosBodyCompaniesIdentifierType0
        api_key = self.api_key

        companies_identifier: dict[str, Any]
        if isinstance(self.companies_identifier, BulkCompanyLogosBodyCompaniesIdentifierType0):
            companies_identifier = self.companies_identifier.to_dict()
        elif isinstance(self.companies_identifier, BulkCompanyLogosBodyCompaniesIdentifierType1):
            companies_identifier = self.companies_identifier.to_dict()
        else:
            companies_identifier = self.companies_identifier.to_dict()



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
            "companiesIdentifier": companies_identifier,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.bulk_company_logos_body_companies_identifier_type_1 import BulkCompanyLogosBodyCompaniesIdentifierType1
        from ..models.bulk_company_logos_body_companies_identifier_type_2 import BulkCompanyLogosBodyCompaniesIdentifierType2
        from ..models.bulk_company_logos_body_companies_identifier_type_0 import BulkCompanyLogosBodyCompaniesIdentifierType0
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        def _parse_companies_identifier(data: object) -> Union['BulkCompanyLogosBodyCompaniesIdentifierType0', 'BulkCompanyLogosBodyCompaniesIdentifierType1', 'BulkCompanyLogosBodyCompaniesIdentifierType2']:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                companies_identifier_type_0 = BulkCompanyLogosBodyCompaniesIdentifierType0.from_dict(data)



                return companies_identifier_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                companies_identifier_type_1 = BulkCompanyLogosBodyCompaniesIdentifierType1.from_dict(data)



                return companies_identifier_type_1
            except: # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            companies_identifier_type_2 = BulkCompanyLogosBodyCompaniesIdentifierType2.from_dict(data)



            return companies_identifier_type_2

        companies_identifier = _parse_companies_identifier(d.pop("companiesIdentifier"))


        bulk_company_logos_body = cls(
            api_key=api_key,
            companies_identifier=companies_identifier,
        )


        bulk_company_logos_body.additional_properties = d
        return bulk_company_logos_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class TextToProfileSearchResponse200OutputSearchParamsEducationType0AnyOfType0ItemFinishedSchoolAtType0Strategy(str, Enum):
    ABSOLUTE = "absolute"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.get_saved_search_run_status_response_200_output_run_status import GetSavedSearchRunStatusResponse200OutputRunStatus
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.get_saved_search_run_status_response_200_output_run_people_stats import GetSavedSearchRunStatusResponse200OutputRunPeopleStats
  from ..models.get_saved_search_run_status_response_200_output_run_companies_stats import GetSavedSearchRunStatusResponse200OutputRunCompaniesStats





T = TypeVar("T", bound="GetSavedSearchRunStatusResponse200OutputRun")



@_attrs_define
class GetSavedSearchRunStatusResponse200OutputRun:
    """ The saved search run details

        Attributes:
            id (str): The ID of the saved search run
            status (GetSavedSearchRunStatusResponse200OutputRunStatus): The status of the saved search run
            companies_stats (GetSavedSearchRunStatusResponse200OutputRunCompaniesStats): The companies stats. This includes
                the number of companies joined, departed, stayed, and returned so far.
            people_stats (GetSavedSearchRunStatusResponse200OutputRunPeopleStats): The people stats. This includes the
                number of people joined, departed, stayed, and returned so far.
            started_at (Union[None, Unset, str]): The date and time the run started (if started)
            completed_at (Union[None, Unset, str]): The date and time the run completed (if completed)
     """

    id: str
    status: GetSavedSearchRunStatusResponse200OutputRunStatus
    companies_stats: 'GetSavedSearchRunStatusResponse200OutputRunCompaniesStats'
    people_stats: 'GetSavedSearchRunStatusResponse200OutputRunPeopleStats'
    started_at: Union[None, Unset, str] = UNSET
    completed_at: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_saved_search_run_status_response_200_output_run_people_stats import GetSavedSearchRunStatusResponse200OutputRunPeopleStats
        from ..models.get_saved_search_run_status_response_200_output_run_companies_stats import GetSavedSearchRunStatusResponse200OutputRunCompaniesStats
        id = self.id

        status = self.status.value

        companies_stats = self.companies_stats.to_dict()

        people_stats = self.people_stats.to_dict()

        started_at: Union[None, Unset, str]
        if isinstance(self.started_at, Unset):
            started_at = UNSET
        else:
            started_at = self.started_at

        completed_at: Union[None, Unset, str]
        if isinstance(self.completed_at, Unset):
            completed_at = UNSET
        else:
            completed_at = self.completed_at


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "id": id,
            "status": status,
            "companiesStats": companies_stats,
            "peopleStats": people_stats,
        })
        if started_at is not UNSET:
            field_dict["startedAt"] = started_at
        if completed_at is not UNSET:
            field_dict["completedAt"] = completed_at

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_saved_search_run_status_response_200_output_run_people_stats import GetSavedSearchRunStatusResponse200OutputRunPeopleStats
        from ..models.get_saved_search_run_status_response_200_output_run_companies_stats import GetSavedSearchRunStatusResponse200OutputRunCompaniesStats
        d = dict(src_dict)
        id = d.pop("id")

        status = GetSavedSearchRunStatusResponse200OutputRunStatus(d.pop("status"))




        companies_stats = GetSavedSearchRunStatusResponse200OutputRunCompaniesStats.from_dict(d.pop("companiesStats"))




        people_stats = GetSavedSearchRunStatusResponse200OutputRunPeopleStats.from_dict(d.pop("peopleStats"))




        def _parse_started_at(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        started_at = _parse_started_at(d.pop("startedAt", UNSET))


        def _parse_completed_at(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        completed_at = _parse_completed_at(d.pop("completedAt", UNSET))


        get_saved_search_run_status_response_200_output_run = cls(
            id=id,
            status=status,
            companies_stats=companies_stats,
            people_stats=people_stats,
            started_at=started_at,
            completed_at=completed_at,
        )


        get_saved_search_run_status_response_200_output_run.additional_properties = d
        return get_saved_search_run_status_response_200_output_run

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsCrunchbaseCategoriesType0AllOfType0ItemType(str, Enum):
    CATEGORY = "category"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsJobPostingsV2Type0AllOfType0ItemIndustryType0Item(str, Enum):
    ADMINISTRATIVE_SERVICES = "Administrative Services"
    AEROSPACE_MILITARY = "Aerospace & Military"
    ARTIFICIAL_INTELLIGENCE = "Artificial Intelligence"
    ARTS_MUSIC = "Arts & Music"
    AUTOMOTIVE = "Automotive"
    BUSINESS_SERVICES = "Business Services"
    CLOUD = "Cloud"
    CONSTRUCTION = "Construction"
    CONSULTING = "Consulting"
    CONSUMER_GOODS = "Consumer Goods"
    CONSUMER_SERVICES = "Consumer Services"
    DESIGN = "Design"
    EDUCATION = "Education"
    ENERGY = "Energy"
    ENTERTAINMENT = "Entertainment"
    ENVIRONMENTAL = "Environmental"
    EVENTS = "Events"
    FARMING_AGRICULTURE = "Farming & Agriculture"
    FINANCE = "Finance"
    FOOD_BEVERAGE = "Food & Beverage"
    GAMING = "Gaming"
    GOVERNMENT = "Government"
    HARDWARE = "Hardware"
    HEALTHCARE = "Healthcare"
    HOSPITALITY = "Hospitality"
    INDUSTRIALS = "Industrials"
    INFORMATION_TECHNOLOGY = "Information Technology"
    INSURANCE = "Insurance"
    LEGAL = "Legal"
    LIFE_SCIENCES = "Life Sciences"
    LOGISTICS = "Logistics"
    MANUFACTURING = "Manufacturing"
    MARKETING_ADVERTISING = "Marketing & Advertising"
    MEDIA = "Media"
    MINING = "Mining"
    NONPROFIT = "Nonprofit"
    PUBLISHING = "Publishing"
    REAL_ESTATE = "Real Estate"
    RETAIL = "Retail"
    SCIENCE_ENGINEERING = "Science & Engineering"
    SECURITY = "Security"
    SOFTWARE = "Software"
    SPORTS = "Sports"
    TELECOM = "Telecom"
    TRADE = "Trade"
    TRANSPORTATION = "Transportation"
    TRAVEL_TOURISM = "Travel & Tourism"
    UTILITIES = "Utilities"
    VENTURE_CAPITAL = "Venture Capital"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.get_excluded_prospects_for_exclusion_list_response_200_output_prospects_item import GetExcludedProspectsForExclusionListResponse200OutputProspectsItem





T = TypeVar("T", bound="GetExcludedProspectsForExclusionListResponse200Output")



@_attrs_define
class GetExcludedProspectsForExclusionListResponse200Output:
    """ 
        Attributes:
            prospects (list['GetExcludedProspectsForExclusionListResponse200OutputProspectsItem']): List of excluded
                prospects
            next_cursor (Union[None, str]): Cursor for the next page of results
            has_more (bool): Whether there are more results available
     """

    prospects: list['GetExcludedProspectsForExclusionListResponse200OutputProspectsItem']
    next_cursor: Union[None, str]
    has_more: bool
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_excluded_prospects_for_exclusion_list_response_200_output_prospects_item import GetExcludedProspectsForExclusionListResponse200OutputProspectsItem
        prospects = []
        for prospects_item_data in self.prospects:
            prospects_item = prospects_item_data.to_dict()
            prospects.append(prospects_item)



        next_cursor: Union[None, str]
        next_cursor = self.next_cursor

        has_more = self.has_more


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "prospects": prospects,
            "nextCursor": next_cursor,
            "hasMore": has_more,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_excluded_prospects_for_exclusion_list_response_200_output_prospects_item import GetExcludedProspectsForExclusionListResponse200OutputProspectsItem
        d = dict(src_dict)
        prospects = []
        _prospects = d.pop("prospects")
        for prospects_item_data in (_prospects):
            prospects_item = GetExcludedProspectsForExclusionListResponse200OutputProspectsItem.from_dict(prospects_item_data)



            prospects.append(prospects_item)


        def _parse_next_cursor(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        next_cursor = _parse_next_cursor(d.pop("nextCursor"))


        has_more = d.pop("hasMore")

        get_excluded_prospects_for_exclusion_list_response_200_output = cls(
            prospects=prospects,
            next_cursor=next_cursor,
            has_more=has_more,
        )


        get_excluded_prospects_for_exclusion_list_response_200_output.additional_properties = d
        return get_excluded_prospects_for_exclusion_list_response_200_output

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="SyncCombinedSearchResponse200OutputProfilesItemTenuresType0ItemDateRange")



@_attrs_define
class SyncCombinedSearchResponse200OutputProfilesItemTenuresType0ItemDateRange:
    """ 
        Attributes:
            gte (Union[None, Unset, str]):
            lte (Union[None, Unset, str]):
     """

    gte: Union[None, Unset, str] = UNSET
    lte: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        gte: Union[None, Unset, str]
        if isinstance(self.gte, Unset):
            gte = UNSET
        else:
            gte = self.gte

        lte: Union[None, Unset, str]
        if isinstance(self.lte, Unset):
            lte = UNSET
        else:
            lte = self.lte


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if gte is not UNSET:
            field_dict["gte"] = gte
        if lte is not UNSET:
            field_dict["lte"] = lte

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_gte(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        gte = _parse_gte(d.pop("gte", UNSET))


        def _parse_lte(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        lte = _parse_lte(d.pop("lte", UNSET))


        sync_combined_search_response_200_output_profiles_item_tenures_type_0_item_date_range = cls(
            gte=gte,
            lte=lte,
        )


        sync_combined_search_response_200_output_profiles_item_tenures_type_0_item_date_range.additional_properties = d
        return sync_combined_search_response_200_output_profiles_item_tenures_type_0_item_date_range

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.profile_reactions_live_fetch_response_200_output_reactions_type_0_item_comment_type_0_author_type_0 import ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0





T = TypeVar("T", bound="ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0")



@_attrs_define
class ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0:
    """ 
        Attributes:
            content (Union[None, Unset, str]):
            author (Union['ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0', None,
                Unset]):
     """

    content: Union[None, Unset, str] = UNSET
    author: Union['ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.profile_reactions_live_fetch_response_200_output_reactions_type_0_item_comment_type_0_author_type_0 import ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0
        content: Union[None, Unset, str]
        if isinstance(self.content, Unset):
            content = UNSET
        else:
            content = self.content

        author: Union[None, Unset, dict[str, Any]]
        if isinstance(self.author, Unset):
            author = UNSET
        elif isinstance(self.author, ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0):
            author = self.author.to_dict()
        else:
            author = self.author


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if content is not UNSET:
            field_dict["content"] = content
        if author is not UNSET:
            field_dict["author"] = author

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.profile_reactions_live_fetch_response_200_output_reactions_type_0_item_comment_type_0_author_type_0 import ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0
        d = dict(src_dict)
        def _parse_content(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        content = _parse_content(d.pop("content", UNSET))


        def _parse_author(data: object) -> Union['ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                author_type_0 = ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0.from_dict(data)



                return author_type_0
            except: # noqa: E722
                pass
            return cast(Union['ProfileReactionsLiveFetchResponse200OutputReactionsType0ItemCommentType0AuthorType0', None, Unset], data)

        author = _parse_author(d.pop("author", UNSET))


        profile_reactions_live_fetch_response_200_output_reactions_type_0_item_comment_type_0 = cls(
            content=content,
            author=author,
        )


        profile_reactions_live_fetch_response_200_output_reactions_type_0_item_comment_type_0.additional_properties = d
        return profile_reactions_live_fetch_response_200_output_reactions_type_0_item_comment_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CompanyCountBodySearchParamsRevenueUSDType0MaxType0SuffixType2Type1(str, Enum):
    B = "B"
    K = "K"
    M = "M"
    T = "T"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.people_search_count_body_search_params_past_job_text_type_0_criteria_item_field import PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItemField
from ..models.people_search_count_body_search_params_past_job_text_type_0_criteria_item_rule import PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItemRule
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItem")



@_attrs_define
class PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItem:
    """ 
        Attributes:
            field (PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItemField):
            rule (PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItemRule):
            text (Union[None, Unset, str]):
     """

    field: PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItemField
    rule: PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItemRule
    text: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        field = self.field.value

        rule = self.rule.value

        text: Union[None, Unset, str]
        if isinstance(self.text, Unset):
            text = UNSET
        else:
            text = self.text


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "field": field,
            "rule": rule,
        })
        if text is not UNSET:
            field_dict["text"] = text

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        field = PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItemField(d.pop("field"))




        rule = PeopleSearchCountBodySearchParamsPastJobTextType0CriteriaItemRule(d.pop("rule"))




        def _parse_text(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        text = _parse_text(d.pop("text", UNSET))


        people_search_count_body_search_params_past_job_text_type_0_criteria_item = cls(
            field=field,
            rule=rule,
            text=text,
        )


        people_search_count_body_search_params_past_job_text_type_0_criteria_item.additional_properties = d
        return people_search_count_body_search_params_past_job_text_type_0_criteria_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0AnyOfType0ItemType1CountryCode(str, Enum):
    ABW = "ABW"
    AFG = "AFG"
    AGO = "AGO"
    AIA = "AIA"
    ALA = "ALA"
    ALB = "ALB"
    AND = "AND"
    ANT = "ANT"
    ARE = "ARE"
    ARG = "ARG"
    ARM = "ARM"
    ASM = "ASM"
    ATA = "ATA"
    ATF = "ATF"
    ATG = "ATG"
    AUS = "AUS"
    AUT = "AUT"
    AZE = "AZE"
    BDI = "BDI"
    BEL = "BEL"
    BEN = "BEN"
    BES = "BES"
    BFA = "BFA"
    BGD = "BGD"
    BGR = "BGR"
    BHR = "BHR"
    BHS = "BHS"
    BIH = "BIH"
    BLM = "BLM"
    BLR = "BLR"
    BLZ = "BLZ"
    BMU = "BMU"
    BOL = "BOL"
    BRA = "BRA"
    BRB = "BRB"
    BRN = "BRN"
    BTN = "BTN"
    BVT = "BVT"
    BWA = "BWA"
    CAF = "CAF"
    CAN = "CAN"
    CCK = "CCK"
    CHE = "CHE"
    CHL = "CHL"
    CHN = "CHN"
    CIV = "CIV"
    CMR = "CMR"
    COD = "COD"
    COG = "COG"
    COK = "COK"
    COL = "COL"
    COM = "COM"
    CPV = "CPV"
    CRI = "CRI"
    CUB = "CUB"
    CUW = "CUW"
    CXR = "CXR"
    CYM = "CYM"
    CYP = "CYP"
    CZE = "CZE"
    DEU = "DEU"
    DJI = "DJI"
    DMA = "DMA"
    DNK = "DNK"
    DOM = "DOM"
    DZA = "DZA"
    ECU = "ECU"
    EGY = "EGY"
    ERI = "ERI"
    ESH = "ESH"
    ESP = "ESP"
    EST = "EST"
    ETH = "ETH"
    FIN = "FIN"
    FJI = "FJI"
    FLK = "FLK"
    FRA = "FRA"
    FRO = "FRO"
    FSM = "FSM"
    GAB = "GAB"
    GBR = "GBR"
    GEO = "GEO"
    GGY = "GGY"
    GHA = "GHA"
    GIB = "GIB"
    GIN = "GIN"
    GLP = "GLP"
    GMB = "GMB"
    GNB = "GNB"
    GNQ = "GNQ"
    GRC = "GRC"
    GRD = "GRD"
    GRL = "GRL"
    GTM = "GTM"
    GUF = "GUF"
    GUM = "GUM"
    GUY = "GUY"
    HKG = "HKG"
    HMD = "HMD"
    HND = "HND"
    HRV = "HRV"
    HTI = "HTI"
    HUN = "HUN"
    IDN = "IDN"
    IMN = "IMN"
    IND = "IND"
    IOT = "IOT"
    IRL = "IRL"
    IRN = "IRN"
    IRQ = "IRQ"
    ISL = "ISL"
    ISR = "ISR"
    ITA = "ITA"
    JAM = "JAM"
    JEY = "JEY"
    JOR = "JOR"
    JPN = "JPN"
    KAZ = "KAZ"
    KEN = "KEN"
    KGZ = "KGZ"
    KHM = "KHM"
    KIR = "KIR"
    KNA = "KNA"
    KOR = "KOR"
    KWT = "KWT"
    LAO = "LAO"
    LBN = "LBN"
    LBR = "LBR"
    LBY = "LBY"
    LCA = "LCA"
    LIE = "LIE"
    LKA = "LKA"
    LSO = "LSO"
    LTU = "LTU"
    LUX = "LUX"
    LVA = "LVA"
    MAC = "MAC"
    MAF = "MAF"
    MAR = "MAR"
    MCO = "MCO"
    MDA = "MDA"
    MDG = "MDG"
    MDV = "MDV"
    MEX = "MEX"
    MHL = "MHL"
    MKD = "MKD"
    MLI = "MLI"
    MLT = "MLT"
    MMR = "MMR"
    MNE = "MNE"
    MNG = "MNG"
    MNP = "MNP"
    MOZ = "MOZ"
    MRT = "MRT"
    MSR = "MSR"
    MTQ = "MTQ"
    MUS = "MUS"
    MWI = "MWI"
    MYS = "MYS"
    MYT = "MYT"
    NAM = "NAM"
    NCL = "NCL"
    NER = "NER"
    NFK = "NFK"
    NGA = "NGA"
    NIC = "NIC"
    NIU = "NIU"
    NLD = "NLD"
    NOR = "NOR"
    NPL = "NPL"
    NRU = "NRU"
    NZL = "NZL"
    OMN = "OMN"
    PAK = "PAK"
    PAN = "PAN"
    PCN = "PCN"
    PER = "PER"
    PHL = "PHL"
    PLW = "PLW"
    PNG = "PNG"
    POL = "POL"
    PRI = "PRI"
    PRK = "PRK"
    PRT = "PRT"
    PRY = "PRY"
    PSE = "PSE"
    PYF = "PYF"
    QAT = "QAT"
    REU = "REU"
    ROU = "ROU"
    RUS = "RUS"
    RWA = "RWA"
    SAU = "SAU"
    SDN = "SDN"
    SEN = "SEN"
    SGP = "SGP"
    SGS = "SGS"
    SHN = "SHN"
    SJM = "SJM"
    SLB = "SLB"
    SLE = "SLE"
    SLV = "SLV"
    SMR = "SMR"
    SOM = "SOM"
    SPM = "SPM"
    SRB = "SRB"
    SSD = "SSD"
    STP = "STP"
    SUR = "SUR"
    SVK = "SVK"
    SVN = "SVN"
    SWE = "SWE"
    SWZ = "SWZ"
    SXM = "SXM"
    SYC = "SYC"
    SYR = "SYR"
    TCA = "TCA"
    TCD = "TCD"
    TGO = "TGO"
    THA = "THA"
    TJK = "TJK"
    TKL = "TKL"
    TKM = "TKM"
    TLS = "TLS"
    TON = "TON"
    TTO = "TTO"
    TUN = "TUN"
    TUR = "TUR"
    TUV = "TUV"
    TWN = "TWN"
    TZA = "TZA"
    UGA = "UGA"
    UKR = "UKR"
    UMI = "UMI"
    URY = "URY"
    USA = "USA"
    UZB = "UZB"
    VAT = "VAT"
    VCT = "VCT"
    VEN = "VEN"
    VGB = "VGB"
    VIR = "VIR"
    VNM = "VNM"
    VUT = "VUT"
    WLF = "WLF"
    WSM = "WSM"
    XKX = "XKX"
    YEM = "YEM"
    ZAF = "ZAF"
    ZMB = "ZMB"
    ZWE = "ZWE"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType2ProfileSearchParamsPastJobTextType0CriteriaItemField(str, Enum):
    ANYWHERE = "anywhere"
    SUMMARY = "summary"
    TITLE = "title"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.profile_posts_live_fetch_response_200_output_data_item_author_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0
  from ..models.profile_posts_live_fetch_response_200_output_data_item_posted_at_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0
  from ..models.profile_posts_live_fetch_response_200_output_data_item_engagement_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0
  from ..models.profile_posts_live_fetch_response_200_output_data_item_video_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemVideoType0
  from ..models.profile_posts_live_fetch_response_200_output_data_item_reshared_post_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0





T = TypeVar("T", bound="ProfilePostsLiveFetchResponse200OutputDataItem")



@_attrs_define
class ProfilePostsLiveFetchResponse200OutputDataItem:
    """ 
        Attributes:
            post_id (str):
            author (Union['ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0', None, Unset]):
            posted_at (Union['ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0', None, Unset]):
            engagement (Union['ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0', None, Unset]):
            image_urls (Union[None, Unset, list[str]]):
            post_url (Union[None, Unset, str]):
            video (Union['ProfilePostsLiveFetchResponse200OutputDataItemVideoType0', None, Unset]):
            caption (Union[None, Unset, str]):
            sub_text (Union[None, Unset, str]):
            reshared_post (Union['ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0', None, Unset]):
     """

    post_id: str
    author: Union['ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0', None, Unset] = UNSET
    posted_at: Union['ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0', None, Unset] = UNSET
    engagement: Union['ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0', None, Unset] = UNSET
    image_urls: Union[None, Unset, list[str]] = UNSET
    post_url: Union[None, Unset, str] = UNSET
    video: Union['ProfilePostsLiveFetchResponse200OutputDataItemVideoType0', None, Unset] = UNSET
    caption: Union[None, Unset, str] = UNSET
    sub_text: Union[None, Unset, str] = UNSET
    reshared_post: Union['ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.profile_posts_live_fetch_response_200_output_data_item_author_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0
        from ..models.profile_posts_live_fetch_response_200_output_data_item_posted_at_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0
        from ..models.profile_posts_live_fetch_response_200_output_data_item_engagement_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0
        from ..models.profile_posts_live_fetch_response_200_output_data_item_video_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemVideoType0
        from ..models.profile_posts_live_fetch_response_200_output_data_item_reshared_post_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0
        post_id = self.post_id

        author: Union[None, Unset, dict[str, Any]]
        if isinstance(self.author, Unset):
            author = UNSET
        elif isinstance(self.author, ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0):
            author = self.author.to_dict()
        else:
            author = self.author

        posted_at: Union[None, Unset, dict[str, Any]]
        if isinstance(self.posted_at, Unset):
            posted_at = UNSET
        elif isinstance(self.posted_at, ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0):
            posted_at = self.posted_at.to_dict()
        else:
            posted_at = self.posted_at

        engagement: Union[None, Unset, dict[str, Any]]
        if isinstance(self.engagement, Unset):
            engagement = UNSET
        elif isinstance(self.engagement, ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0):
            engagement = self.engagement.to_dict()
        else:
            engagement = self.engagement

        image_urls: Union[None, Unset, list[str]]
        if isinstance(self.image_urls, Unset):
            image_urls = UNSET
        elif isinstance(self.image_urls, list):
            image_urls = self.image_urls


        else:
            image_urls = self.image_urls

        post_url: Union[None, Unset, str]
        if isinstance(self.post_url, Unset):
            post_url = UNSET
        else:
            post_url = self.post_url

        video: Union[None, Unset, dict[str, Any]]
        if isinstance(self.video, Unset):
            video = UNSET
        elif isinstance(self.video, ProfilePostsLiveFetchResponse200OutputDataItemVideoType0):
            video = self.video.to_dict()
        else:
            video = self.video

        caption: Union[None, Unset, str]
        if isinstance(self.caption, Unset):
            caption = UNSET
        else:
            caption = self.caption

        sub_text: Union[None, Unset, str]
        if isinstance(self.sub_text, Unset):
            sub_text = UNSET
        else:
            sub_text = self.sub_text

        reshared_post: Union[None, Unset, dict[str, Any]]
        if isinstance(self.reshared_post, Unset):
            reshared_post = UNSET
        elif isinstance(self.reshared_post, ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0):
            reshared_post = self.reshared_post.to_dict()
        else:
            reshared_post = self.reshared_post


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "postId": post_id,
        })
        if author is not UNSET:
            field_dict["author"] = author
        if posted_at is not UNSET:
            field_dict["postedAt"] = posted_at
        if engagement is not UNSET:
            field_dict["engagement"] = engagement
        if image_urls is not UNSET:
            field_dict["imageUrls"] = image_urls
        if post_url is not UNSET:
            field_dict["postUrl"] = post_url
        if video is not UNSET:
            field_dict["video"] = video
        if caption is not UNSET:
            field_dict["caption"] = caption
        if sub_text is not UNSET:
            field_dict["subText"] = sub_text
        if reshared_post is not UNSET:
            field_dict["resharedPost"] = reshared_post

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.profile_posts_live_fetch_response_200_output_data_item_author_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0
        from ..models.profile_posts_live_fetch_response_200_output_data_item_posted_at_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0
        from ..models.profile_posts_live_fetch_response_200_output_data_item_engagement_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0
        from ..models.profile_posts_live_fetch_response_200_output_data_item_video_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemVideoType0
        from ..models.profile_posts_live_fetch_response_200_output_data_item_reshared_post_type_0 import ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0
        d = dict(src_dict)
        post_id = d.pop("postId")

        def _parse_author(data: object) -> Union['ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                author_type_0 = ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0.from_dict(data)



                return author_type_0
            except: # noqa: E722
                pass
            return cast(Union['ProfilePostsLiveFetchResponse200OutputDataItemAuthorType0', None, Unset], data)

        author = _parse_author(d.pop("author", UNSET))


        def _parse_posted_at(data: object) -> Union['ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                posted_at_type_0 = ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0.from_dict(data)



                return posted_at_type_0
            except: # noqa: E722
                pass
            return cast(Union['ProfilePostsLiveFetchResponse200OutputDataItemPostedAtType0', None, Unset], data)

        posted_at = _parse_posted_at(d.pop("postedAt", UNSET))


        def _parse_engagement(data: object) -> Union['ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                engagement_type_0 = ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0.from_dict(data)



                return engagement_type_0
            except: # noqa: E722
                pass
            return cast(Union['ProfilePostsLiveFetchResponse200OutputDataItemEngagementType0', None, Unset], data)

        engagement = _parse_engagement(d.pop("engagement", UNSET))


        def _parse_image_urls(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                image_urls_type_0 = cast(list[str], data)

                return image_urls_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        image_urls = _parse_image_urls(d.pop("imageUrls", UNSET))


        def _parse_post_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        post_url = _parse_post_url(d.pop("postUrl", UNSET))


        def _parse_video(data: object) -> Union['ProfilePostsLiveFetchResponse200OutputDataItemVideoType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                video_type_0 = ProfilePostsLiveFetchResponse200OutputDataItemVideoType0.from_dict(data)



                return video_type_0
            except: # noqa: E722
                pass
            return cast(Union['ProfilePostsLiveFetchResponse200OutputDataItemVideoType0', None, Unset], data)

        video = _parse_video(d.pop("video", UNSET))


        def _parse_caption(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        caption = _parse_caption(d.pop("caption", UNSET))


        def _parse_sub_text(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        sub_text = _parse_sub_text(d.pop("subText", UNSET))


        def _parse_reshared_post(data: object) -> Union['ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                reshared_post_type_0 = ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0.from_dict(data)



                return reshared_post_type_0
            except: # noqa: E722
                pass
            return cast(Union['ProfilePostsLiveFetchResponse200OutputDataItemResharedPostType0', None, Unset], data)

        reshared_post = _parse_reshared_post(d.pop("resharedPost", UNSET))


        profile_posts_live_fetch_response_200_output_data_item = cls(
            post_id=post_id,
            author=author,
            posted_at=posted_at,
            engagement=engagement,
            image_urls=image_urls,
            post_url=post_url,
            video=video,
            caption=caption,
            sub_text=sub_text,
            reshared_post=reshared_post,
        )


        profile_posts_live_fetch_response_200_output_data_item.additional_properties = d
        return profile_posts_live_fetch_response_200_output_data_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.bulk_company_logos_body_companies_identifier_type_0_type import BulkCompanyLogosBodyCompaniesIdentifierType0Type
from typing import cast






T = TypeVar("T", bound="BulkCompanyLogosBodyCompaniesIdentifierType0")



@_attrs_define
class BulkCompanyLogosBodyCompaniesIdentifierType0:
    """ 
        Attributes:
            type_ (BulkCompanyLogosBodyCompaniesIdentifierType0Type):
            domains (list[str]):
     """

    type_: BulkCompanyLogosBodyCompaniesIdentifierType0Type
    domains: list[str]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_.value

        domains = self.domains




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "domains": domains,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = BulkCompanyLogosBodyCompaniesIdentifierType0Type(d.pop("type"))




        domains = cast(list[str], d.pop("domains"))


        bulk_company_logos_body_companies_identifier_type_0 = cls(
            type_=type_,
            domains=domains,
        )


        bulk_company_logos_body_companies_identifier_type_0.additional_properties = d
        return bulk_company_logos_body_companies_identifier_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.investment_search_body_search_params_type_0_investor_type_type_1 import InvestmentSearchBodySearchParamsType0InvestorTypeType1
from ..models.investment_search_body_search_params_type_0_investor_type_type_2_type_1 import InvestmentSearchBodySearchParamsType0InvestorTypeType2Type1
from ..models.investment_search_body_search_params_type_0_investor_type_type_3_type_1 import InvestmentSearchBodySearchParamsType0InvestorTypeType3Type1
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.investment_search_body_search_params_type_0_raised_amount_usd_type_0 import InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0
  from ..models.investment_search_body_search_params_type_0_state_name_type_0 import InvestmentSearchBodySearchParamsType0StateNameType0
  from ..models.investment_search_body_search_params_type_0_round_type_type_0 import InvestmentSearchBodySearchParamsType0RoundTypeType0
  from ..models.investment_search_body_search_params_type_0_country_code_type_0 import InvestmentSearchBodySearchParamsType0CountryCodeType0
  from ..models.investment_search_body_search_params_type_0_round_date_type_0 import InvestmentSearchBodySearchParamsType0RoundDateType0
  from ..models.investment_search_body_search_params_type_0_sorting_type_0 import InvestmentSearchBodySearchParamsType0SortingType0
  from ..models.investment_search_body_search_params_type_0_post_money_valuation_usd_type_0 import InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0
  from ..models.investment_search_body_search_params_type_0_investor_country_code_type_0 import InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0





T = TypeVar("T", bound="InvestmentSearchBodySearchParamsType0")



@_attrs_define
class InvestmentSearchBodySearchParamsType0:
    """ Investment search filter parameters. If not provided, returns all investments (subject to pagination)

        Attributes:
            investor_name (Union[None, Unset, str]): Filter by investor name (partial match, case-insensitive). Use ILIKE
                pattern matching.
            investor_type (Union[InvestmentSearchBodySearchParamsType0InvestorTypeType1,
                InvestmentSearchBodySearchParamsType0InvestorTypeType2Type1,
                InvestmentSearchBodySearchParamsType0InvestorTypeType3Type1, None, Unset]): Filter by investor type: 'person'
                for individuals, 'organization' for firms, 'either' to include both types. Pass null/undefined to include both
                types (same as 'either')
            investor_country_code (Union['InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0', None, Unset]):
                Investor country or region filter with include/exclude pattern. Region codes like X-ANGLOSPHERE expand to
                multiple countries (USA, GBR, AUS, etc.)
            investor_domain (Union[None, Unset, str]): Filter by investor domain (exact match). For example, 'techstars.com'
                to find all investments made by Techstars
            investor_crunchbase_slug (Union[None, Unset, str]): Filter by investor Crunchbase slug (exact match). For
                example, 'sequoia-capital' to find all investments made by Sequoia Capital
            company_name (Union[None, Unset, str]): Filter by company name (partial match, case-insensitive). Use ILIKE
                pattern matching.
            company_domain (Union[None, Unset, str]): Filter by company domain (exact match)
            company_linkedin_url (Union[None, Unset, str]): Filter by company LinkedIn URL. Accepts either full URL (e.g.,
                'https://www.linkedin.com/company/fiber-ai/') or slug (e.g., 'fiber-ai'). You can also use LinkedIn organization
                ID in the slug (e.g., 'https://www.linkedin.com/company/123456789/' or just '123456789')
            round_type (Union['InvestmentSearchBodySearchParamsType0RoundTypeType0', None, Unset]): Round type filter with
                include/exclude pattern. Examples: include: ['series_a', 'seed']
            round_date (Union['InvestmentSearchBodySearchParamsType0RoundDateType0', None, Unset]): Filter by funding round
                announcement date (date range)
            raised_amount_usd (Union['InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0', None, Unset]): Filter by
                amount raised in USD (range). For example, min: 5000000 to find rounds with at least $5M raised
            post_money_valuation_usd (Union['InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0', None,
                Unset]): Filter by post-money valuation in USD (range)
            country_code (Union['InvestmentSearchBodySearchParamsType0CountryCodeType0', None, Unset]): Round location
                country or region filter with include/exclude pattern. Region codes like X-ANGLOSPHERE expand to multiple
                countries (USA, GBR, AUS, etc.)
            state_name (Union['InvestmentSearchBodySearchParamsType0StateNameType0', None, Unset]): Round location state
                name filter with include/exclude pattern. Use full state names (e.g., 'California', 'England', 'New York').
                State codes like 'CA' or 'NY' are not accepted.
            city (Union[None, Unset, str]): Filter by round location city (partial match, case-insensitive). Use ILIKE
                pattern matching.
            was_lead_investor (Union[None, Unset, bool]): Filter by whether the investor was a lead investor in the round
            min_investor_count (Union[None, Unset, int]): Filter by minimum number of investors in the funding round
            sorting (Union['InvestmentSearchBodySearchParamsType0SortingType0', None, Unset]): Sorting configuration. If
                provided, field is required. Defaults to round_date DESC if not provided.
     """

    investor_name: Union[None, Unset, str] = UNSET
    investor_type: Union[InvestmentSearchBodySearchParamsType0InvestorTypeType1, InvestmentSearchBodySearchParamsType0InvestorTypeType2Type1, InvestmentSearchBodySearchParamsType0InvestorTypeType3Type1, None, Unset] = UNSET
    investor_country_code: Union['InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0', None, Unset] = UNSET
    investor_domain: Union[None, Unset, str] = UNSET
    investor_crunchbase_slug: Union[None, Unset, str] = UNSET
    company_name: Union[None, Unset, str] = UNSET
    company_domain: Union[None, Unset, str] = UNSET
    company_linkedin_url: Union[None, Unset, str] = UNSET
    round_type: Union['InvestmentSearchBodySearchParamsType0RoundTypeType0', None, Unset] = UNSET
    round_date: Union['InvestmentSearchBodySearchParamsType0RoundDateType0', None, Unset] = UNSET
    raised_amount_usd: Union['InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0', None, Unset] = UNSET
    post_money_valuation_usd: Union['InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0', None, Unset] = UNSET
    country_code: Union['InvestmentSearchBodySearchParamsType0CountryCodeType0', None, Unset] = UNSET
    state_name: Union['InvestmentSearchBodySearchParamsType0StateNameType0', None, Unset] = UNSET
    city: Union[None, Unset, str] = UNSET
    was_lead_investor: Union[None, Unset, bool] = UNSET
    min_investor_count: Union[None, Unset, int] = UNSET
    sorting: Union['InvestmentSearchBodySearchParamsType0SortingType0', None, Unset] = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.investment_search_body_search_params_type_0_raised_amount_usd_type_0 import InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0
        from ..models.investment_search_body_search_params_type_0_state_name_type_0 import InvestmentSearchBodySearchParamsType0StateNameType0
        from ..models.investment_search_body_search_params_type_0_round_type_type_0 import InvestmentSearchBodySearchParamsType0RoundTypeType0
        from ..models.investment_search_body_search_params_type_0_country_code_type_0 import InvestmentSearchBodySearchParamsType0CountryCodeType0
        from ..models.investment_search_body_search_params_type_0_round_date_type_0 import InvestmentSearchBodySearchParamsType0RoundDateType0
        from ..models.investment_search_body_search_params_type_0_sorting_type_0 import InvestmentSearchBodySearchParamsType0SortingType0
        from ..models.investment_search_body_search_params_type_0_post_money_valuation_usd_type_0 import InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0
        from ..models.investment_search_body_search_params_type_0_investor_country_code_type_0 import InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0
        investor_name: Union[None, Unset, str]
        if isinstance(self.investor_name, Unset):
            investor_name = UNSET
        else:
            investor_name = self.investor_name

        investor_type: Union[None, Unset, str]
        if isinstance(self.investor_type, Unset):
            investor_type = UNSET
        elif isinstance(self.investor_type, InvestmentSearchBodySearchParamsType0InvestorTypeType1):
            investor_type = self.investor_type.value
        elif isinstance(self.investor_type, InvestmentSearchBodySearchParamsType0InvestorTypeType2Type1):
            investor_type = self.investor_type.value
        elif isinstance(self.investor_type, InvestmentSearchBodySearchParamsType0InvestorTypeType3Type1):
            investor_type = self.investor_type.value
        else:
            investor_type = self.investor_type

        investor_country_code: Union[None, Unset, dict[str, Any]]
        if isinstance(self.investor_country_code, Unset):
            investor_country_code = UNSET
        elif isinstance(self.investor_country_code, InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0):
            investor_country_code = self.investor_country_code.to_dict()
        else:
            investor_country_code = self.investor_country_code

        investor_domain: Union[None, Unset, str]
        if isinstance(self.investor_domain, Unset):
            investor_domain = UNSET
        else:
            investor_domain = self.investor_domain

        investor_crunchbase_slug: Union[None, Unset, str]
        if isinstance(self.investor_crunchbase_slug, Unset):
            investor_crunchbase_slug = UNSET
        else:
            investor_crunchbase_slug = self.investor_crunchbase_slug

        company_name: Union[None, Unset, str]
        if isinstance(self.company_name, Unset):
            company_name = UNSET
        else:
            company_name = self.company_name

        company_domain: Union[None, Unset, str]
        if isinstance(self.company_domain, Unset):
            company_domain = UNSET
        else:
            company_domain = self.company_domain

        company_linkedin_url: Union[None, Unset, str]
        if isinstance(self.company_linkedin_url, Unset):
            company_linkedin_url = UNSET
        else:
            company_linkedin_url = self.company_linkedin_url

        round_type: Union[None, Unset, dict[str, Any]]
        if isinstance(self.round_type, Unset):
            round_type = UNSET
        elif isinstance(self.round_type, InvestmentSearchBodySearchParamsType0RoundTypeType0):
            round_type = self.round_type.to_dict()
        else:
            round_type = self.round_type

        round_date: Union[None, Unset, dict[str, Any]]
        if isinstance(self.round_date, Unset):
            round_date = UNSET
        elif isinstance(self.round_date, InvestmentSearchBodySearchParamsType0RoundDateType0):
            round_date = self.round_date.to_dict()
        else:
            round_date = self.round_date

        raised_amount_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.raised_amount_usd, Unset):
            raised_amount_usd = UNSET
        elif isinstance(self.raised_amount_usd, InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0):
            raised_amount_usd = self.raised_amount_usd.to_dict()
        else:
            raised_amount_usd = self.raised_amount_usd

        post_money_valuation_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.post_money_valuation_usd, Unset):
            post_money_valuation_usd = UNSET
        elif isinstance(self.post_money_valuation_usd, InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0):
            post_money_valuation_usd = self.post_money_valuation_usd.to_dict()
        else:
            post_money_valuation_usd = self.post_money_valuation_usd

        country_code: Union[None, Unset, dict[str, Any]]
        if isinstance(self.country_code, Unset):
            country_code = UNSET
        elif isinstance(self.country_code, InvestmentSearchBodySearchParamsType0CountryCodeType0):
            country_code = self.country_code.to_dict()
        else:
            country_code = self.country_code

        state_name: Union[None, Unset, dict[str, Any]]
        if isinstance(self.state_name, Unset):
            state_name = UNSET
        elif isinstance(self.state_name, InvestmentSearchBodySearchParamsType0StateNameType0):
            state_name = self.state_name.to_dict()
        else:
            state_name = self.state_name

        city: Union[None, Unset, str]
        if isinstance(self.city, Unset):
            city = UNSET
        else:
            city = self.city

        was_lead_investor: Union[None, Unset, bool]
        if isinstance(self.was_lead_investor, Unset):
            was_lead_investor = UNSET
        else:
            was_lead_investor = self.was_lead_investor

        min_investor_count: Union[None, Unset, int]
        if isinstance(self.min_investor_count, Unset):
            min_investor_count = UNSET
        else:
            min_investor_count = self.min_investor_count

        sorting: Union[None, Unset, dict[str, Any]]
        if isinstance(self.sorting, Unset):
            sorting = UNSET
        elif isinstance(self.sorting, InvestmentSearchBodySearchParamsType0SortingType0):
            sorting = self.sorting.to_dict()
        else:
            sorting = self.sorting


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if investor_name is not UNSET:
            field_dict["investorName"] = investor_name
        if investor_type is not UNSET:
            field_dict["investorType"] = investor_type
        if investor_country_code is not UNSET:
            field_dict["investorCountryCode"] = investor_country_code
        if investor_domain is not UNSET:
            field_dict["investorDomain"] = investor_domain
        if investor_crunchbase_slug is not UNSET:
            field_dict["investorCrunchbaseSlug"] = investor_crunchbase_slug
        if company_name is not UNSET:
            field_dict["companyName"] = company_name
        if company_domain is not UNSET:
            field_dict["companyDomain"] = company_domain
        if company_linkedin_url is not UNSET:
            field_dict["companyLinkedinUrl"] = company_linkedin_url
        if round_type is not UNSET:
            field_dict["roundType"] = round_type
        if round_date is not UNSET:
            field_dict["roundDate"] = round_date
        if raised_amount_usd is not UNSET:
            field_dict["raisedAmountUSD"] = raised_amount_usd
        if post_money_valuation_usd is not UNSET:
            field_dict["postMoneyValuationUSD"] = post_money_valuation_usd
        if country_code is not UNSET:
            field_dict["countryCode"] = country_code
        if state_name is not UNSET:
            field_dict["stateName"] = state_name
        if city is not UNSET:
            field_dict["city"] = city
        if was_lead_investor is not UNSET:
            field_dict["wasLeadInvestor"] = was_lead_investor
        if min_investor_count is not UNSET:
            field_dict["minInvestorCount"] = min_investor_count
        if sorting is not UNSET:
            field_dict["sorting"] = sorting

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.investment_search_body_search_params_type_0_raised_amount_usd_type_0 import InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0
        from ..models.investment_search_body_search_params_type_0_state_name_type_0 import InvestmentSearchBodySearchParamsType0StateNameType0
        from ..models.investment_search_body_search_params_type_0_round_type_type_0 import InvestmentSearchBodySearchParamsType0RoundTypeType0
        from ..models.investment_search_body_search_params_type_0_country_code_type_0 import InvestmentSearchBodySearchParamsType0CountryCodeType0
        from ..models.investment_search_body_search_params_type_0_round_date_type_0 import InvestmentSearchBodySearchParamsType0RoundDateType0
        from ..models.investment_search_body_search_params_type_0_sorting_type_0 import InvestmentSearchBodySearchParamsType0SortingType0
        from ..models.investment_search_body_search_params_type_0_post_money_valuation_usd_type_0 import InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0
        from ..models.investment_search_body_search_params_type_0_investor_country_code_type_0 import InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0
        d = dict(src_dict)
        def _parse_investor_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        investor_name = _parse_investor_name(d.pop("investorName", UNSET))


        def _parse_investor_type(data: object) -> Union[InvestmentSearchBodySearchParamsType0InvestorTypeType1, InvestmentSearchBodySearchParamsType0InvestorTypeType2Type1, InvestmentSearchBodySearchParamsType0InvestorTypeType3Type1, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                investor_type_type_1 = InvestmentSearchBodySearchParamsType0InvestorTypeType1(data)



                return investor_type_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                investor_type_type_2_type_1 = InvestmentSearchBodySearchParamsType0InvestorTypeType2Type1(data)



                return investor_type_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                investor_type_type_3_type_1 = InvestmentSearchBodySearchParamsType0InvestorTypeType3Type1(data)



                return investor_type_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[InvestmentSearchBodySearchParamsType0InvestorTypeType1, InvestmentSearchBodySearchParamsType0InvestorTypeType2Type1, InvestmentSearchBodySearchParamsType0InvestorTypeType3Type1, None, Unset], data)

        investor_type = _parse_investor_type(d.pop("investorType", UNSET))


        def _parse_investor_country_code(data: object) -> Union['InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                investor_country_code_type_0 = InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0.from_dict(data)



                return investor_country_code_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0InvestorCountryCodeType0', None, Unset], data)

        investor_country_code = _parse_investor_country_code(d.pop("investorCountryCode", UNSET))


        def _parse_investor_domain(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        investor_domain = _parse_investor_domain(d.pop("investorDomain", UNSET))


        def _parse_investor_crunchbase_slug(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        investor_crunchbase_slug = _parse_investor_crunchbase_slug(d.pop("investorCrunchbaseSlug", UNSET))


        def _parse_company_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        company_name = _parse_company_name(d.pop("companyName", UNSET))


        def _parse_company_domain(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        company_domain = _parse_company_domain(d.pop("companyDomain", UNSET))


        def _parse_company_linkedin_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        company_linkedin_url = _parse_company_linkedin_url(d.pop("companyLinkedinUrl", UNSET))


        def _parse_round_type(data: object) -> Union['InvestmentSearchBodySearchParamsType0RoundTypeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                round_type_type_0 = InvestmentSearchBodySearchParamsType0RoundTypeType0.from_dict(data)



                return round_type_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0RoundTypeType0', None, Unset], data)

        round_type = _parse_round_type(d.pop("roundType", UNSET))


        def _parse_round_date(data: object) -> Union['InvestmentSearchBodySearchParamsType0RoundDateType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                round_date_type_0 = InvestmentSearchBodySearchParamsType0RoundDateType0.from_dict(data)



                return round_date_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0RoundDateType0', None, Unset], data)

        round_date = _parse_round_date(d.pop("roundDate", UNSET))


        def _parse_raised_amount_usd(data: object) -> Union['InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                raised_amount_usd_type_0 = InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0.from_dict(data)



                return raised_amount_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0RaisedAmountUSDType0', None, Unset], data)

        raised_amount_usd = _parse_raised_amount_usd(d.pop("raisedAmountUSD", UNSET))


        def _parse_post_money_valuation_usd(data: object) -> Union['InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                post_money_valuation_usd_type_0 = InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0.from_dict(data)



                return post_money_valuation_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0PostMoneyValuationUSDType0', None, Unset], data)

        post_money_valuation_usd = _parse_post_money_valuation_usd(d.pop("postMoneyValuationUSD", UNSET))


        def _parse_country_code(data: object) -> Union['InvestmentSearchBodySearchParamsType0CountryCodeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                country_code_type_0 = InvestmentSearchBodySearchParamsType0CountryCodeType0.from_dict(data)



                return country_code_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0CountryCodeType0', None, Unset], data)

        country_code = _parse_country_code(d.pop("countryCode", UNSET))


        def _parse_state_name(data: object) -> Union['InvestmentSearchBodySearchParamsType0StateNameType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                state_name_type_0 = InvestmentSearchBodySearchParamsType0StateNameType0.from_dict(data)



                return state_name_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0StateNameType0', None, Unset], data)

        state_name = _parse_state_name(d.pop("stateName", UNSET))


        def _parse_city(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        city = _parse_city(d.pop("city", UNSET))


        def _parse_was_lead_investor(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        was_lead_investor = _parse_was_lead_investor(d.pop("wasLeadInvestor", UNSET))


        def _parse_min_investor_count(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        min_investor_count = _parse_min_investor_count(d.pop("minInvestorCount", UNSET))


        def _parse_sorting(data: object) -> Union['InvestmentSearchBodySearchParamsType0SortingType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                sorting_type_0 = InvestmentSearchBodySearchParamsType0SortingType0.from_dict(data)



                return sorting_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0SortingType0', None, Unset], data)

        sorting = _parse_sorting(d.pop("sorting", UNSET))


        investment_search_body_search_params_type_0 = cls(
            investor_name=investor_name,
            investor_type=investor_type,
            investor_country_code=investor_country_code,
            investor_domain=investor_domain,
            investor_crunchbase_slug=investor_crunchbase_slug,
            company_name=company_name,
            company_domain=company_domain,
            company_linkedin_url=company_linkedin_url,
            round_type=round_type,
            round_date=round_date,
            raised_amount_usd=raised_amount_usd,
            post_money_valuation_usd=post_money_valuation_usd,
            country_code=country_code,
            state_name=state_name,
            city=city,
            was_lead_investor=was_lead_investor,
            min_investor_count=min_investor_count,
            sorting=sorting,
        )

        return investment_search_body_search_params_type_0




from enum import Enum

class CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType6Rule(str, Enum):
    INDUSTRY = "industry"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.company_search_response_200_output_data_item_investment_stats_type_0_investments_by_stage_type_0_item import CompanySearchResponse200OutputDataItemInvestmentStatsType0InvestmentsByStageType0Item





T = TypeVar("T", bound="CompanySearchResponse200OutputDataItemInvestmentStatsType0")



@_attrs_define
class CompanySearchResponse200OutputDataItemInvestmentStatsType0:
    """ 
        Attributes:
            investments_by_stage (Union[None, Unset,
                list['CompanySearchResponse200OutputDataItemInvestmentStatsType0InvestmentsByStageType0Item']]):
            lead_investment_rate (Union[None, Unset, float]):
            lead_investment_count (Union[None, Unset, float]):
            total_investment_count (Union[None, Unset, float]):
            last_investment_date (Union[None, Unset, str]):
     """

    investments_by_stage: Union[None, Unset, list['CompanySearchResponse200OutputDataItemInvestmentStatsType0InvestmentsByStageType0Item']] = UNSET
    lead_investment_rate: Union[None, Unset, float] = UNSET
    lead_investment_count: Union[None, Unset, float] = UNSET
    total_investment_count: Union[None, Unset, float] = UNSET
    last_investment_date: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.company_search_response_200_output_data_item_investment_stats_type_0_investments_by_stage_type_0_item import CompanySearchResponse200OutputDataItemInvestmentStatsType0InvestmentsByStageType0Item
        investments_by_stage: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.investments_by_stage, Unset):
            investments_by_stage = UNSET
        elif isinstance(self.investments_by_stage, list):
            investments_by_stage = []
            for investments_by_stage_type_0_item_data in self.investments_by_stage:
                investments_by_stage_type_0_item = investments_by_stage_type_0_item_data.to_dict()
                investments_by_stage.append(investments_by_stage_type_0_item)


        else:
            investments_by_stage = self.investments_by_stage

        lead_investment_rate: Union[None, Unset, float]
        if isinstance(self.lead_investment_rate, Unset):
            lead_investment_rate = UNSET
        else:
            lead_investment_rate = self.lead_investment_rate

        lead_investment_count: Union[None, Unset, float]
        if isinstance(self.lead_investment_count, Unset):
            lead_investment_count = UNSET
        else:
            lead_investment_count = self.lead_investment_count

        total_investment_count: Union[None, Unset, float]
        if isinstance(self.total_investment_count, Unset):
            total_investment_count = UNSET
        else:
            total_investment_count = self.total_investment_count

        last_investment_date: Union[None, Unset, str]
        if isinstance(self.last_investment_date, Unset):
            last_investment_date = UNSET
        else:
            last_investment_date = self.last_investment_date


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if investments_by_stage is not UNSET:
            field_dict["investments_by_stage"] = investments_by_stage
        if lead_investment_rate is not UNSET:
            field_dict["lead_investment_rate"] = lead_investment_rate
        if lead_investment_count is not UNSET:
            field_dict["lead_investment_count"] = lead_investment_count
        if total_investment_count is not UNSET:
            field_dict["total_investment_count"] = total_investment_count
        if last_investment_date is not UNSET:
            field_dict["last_investment_date"] = last_investment_date

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.company_search_response_200_output_data_item_investment_stats_type_0_investments_by_stage_type_0_item import CompanySearchResponse200OutputDataItemInvestmentStatsType0InvestmentsByStageType0Item
        d = dict(src_dict)
        def _parse_investments_by_stage(data: object) -> Union[None, Unset, list['CompanySearchResponse200OutputDataItemInvestmentStatsType0InvestmentsByStageType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                investments_by_stage_type_0 = []
                _investments_by_stage_type_0 = data
                for investments_by_stage_type_0_item_data in (_investments_by_stage_type_0):
                    investments_by_stage_type_0_item = CompanySearchResponse200OutputDataItemInvestmentStatsType0InvestmentsByStageType0Item.from_dict(investments_by_stage_type_0_item_data)



                    investments_by_stage_type_0.append(investments_by_stage_type_0_item)

                return investments_by_stage_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['CompanySearchResponse200OutputDataItemInvestmentStatsType0InvestmentsByStageType0Item']], data)

        investments_by_stage = _parse_investments_by_stage(d.pop("investments_by_stage", UNSET))


        def _parse_lead_investment_rate(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lead_investment_rate = _parse_lead_investment_rate(d.pop("lead_investment_rate", UNSET))


        def _parse_lead_investment_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lead_investment_count = _parse_lead_investment_count(d.pop("lead_investment_count", UNSET))


        def _parse_total_investment_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        total_investment_count = _parse_total_investment_count(d.pop("total_investment_count", UNSET))


        def _parse_last_investment_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        last_investment_date = _parse_last_investment_date(d.pop("last_investment_date", UNSET))


        company_search_response_200_output_data_item_investment_stats_type_0 = cls(
            investments_by_stage=investments_by_stage,
            lead_investment_rate=lead_investment_rate,
            lead_investment_count=lead_investment_count,
            total_investment_count=total_investment_count,
            last_investment_date=last_investment_date,
        )


        company_search_response_200_output_data_item_investment_stats_type_0.additional_properties = d
        return company_search_response_200_output_data_item_investment_stats_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import IntEnum

class SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0LowerBoundExclusiveType0(IntEnum):
    VALUE_0 = 0

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0_max_type_0_suffix_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType1
from ..models.text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0_max_type_0_suffix_type_2_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType2Type1
from ..models.text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0_max_type_0_suffix_type_3_type_1 import TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType3Type1
from typing import cast, Union






T = TypeVar("T", bound="TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0")



@_attrs_define
class TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0:
    """ 
        Attributes:
            quantity (float):
            suffix (Union[None, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType1,
                TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType2Type1,
                TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType3Type1]):
     """

    quantity: float
    suffix: Union[None, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType1, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType2Type1, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType3Type1]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        quantity = self.quantity

        suffix: Union[None, str]
        if isinstance(self.suffix, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType1):
            suffix = self.suffix.value
        elif isinstance(self.suffix, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType2Type1):
            suffix = self.suffix.value
        elif isinstance(self.suffix, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType3Type1):
            suffix = self.suffix.value
        else:
            suffix = self.suffix


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "quantity": quantity,
            "suffix": suffix,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        quantity = d.pop("quantity")

        def _parse_suffix(data: object) -> Union[None, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType1, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType2Type1, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType3Type1]:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                suffix_type_1 = TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType1(data)



                return suffix_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                suffix_type_2_type_1 = TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType2Type1(data)



                return suffix_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                suffix_type_3_type_1 = TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType3Type1(data)



                return suffix_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[None, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType1, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType2Type1, TextToCompanySearchParamsResponse200OutputSearchParamsRevenueUSDType0MaxType0SuffixType3Type1], data)

        suffix = _parse_suffix(d.pop("suffix"))


        text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0_max_type_0 = cls(
            quantity=quantity,
            suffix=suffix,
        )


        text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0_max_type_0.additional_properties = d
        return text_to_company_search_params_response_200_output_search_params_revenue_usd_type_0_max_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.start_local_business_search_body_data_item_type_0_source import StartLocalBusinessSearchBodyDataItemType0Source
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="StartLocalBusinessSearchBodyDataItemType0")



@_attrs_define
class StartLocalBusinessSearchBodyDataItemType0:
    """ 
        Attributes:
            source (StartLocalBusinessSearchBodyDataItemType0Source):
            company_name (str): Business name
            domain (Union[None, Unset, str]): Domain of the business
            context (Union[None, Unset, str]): Context of the business like its industry, etc.
            city (Union[None, Unset, str]): City of the business
            state (Union[None, Unset, str]): State of the business
            state_code (Union[None, Unset, str]): State code of the business
            country_name (Union[None, Unset, str]): Country name of the business
            country_3_letter_code (Union[None, Unset, str]): Country 3 letter code of the business
            address (Union[None, Unset, str]): Address of the business
     """

    source: StartLocalBusinessSearchBodyDataItemType0Source
    company_name: str
    domain: Union[None, Unset, str] = UNSET
    context: Union[None, Unset, str] = UNSET
    city: Union[None, Unset, str] = UNSET
    state: Union[None, Unset, str] = UNSET
    state_code: Union[None, Unset, str] = UNSET
    country_name: Union[None, Unset, str] = UNSET
    country_3_letter_code: Union[None, Unset, str] = UNSET
    address: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        source = self.source.value

        company_name = self.company_name

        domain: Union[None, Unset, str]
        if isinstance(self.domain, Unset):
            domain = UNSET
        else:
            domain = self.domain

        context: Union[None, Unset, str]
        if isinstance(self.context, Unset):
            context = UNSET
        else:
            context = self.context

        city: Union[None, Unset, str]
        if isinstance(self.city, Unset):
            city = UNSET
        else:
            city = self.city

        state: Union[None, Unset, str]
        if isinstance(self.state, Unset):
            state = UNSET
        else:
            state = self.state

        state_code: Union[None, Unset, str]
        if isinstance(self.state_code, Unset):
            state_code = UNSET
        else:
            state_code = self.state_code

        country_name: Union[None, Unset, str]
        if isinstance(self.country_name, Unset):
            country_name = UNSET
        else:
            country_name = self.country_name

        country_3_letter_code: Union[None, Unset, str]
        if isinstance(self.country_3_letter_code, Unset):
            country_3_letter_code = UNSET
        else:
            country_3_letter_code = self.country_3_letter_code

        address: Union[None, Unset, str]
        if isinstance(self.address, Unset):
            address = UNSET
        else:
            address = self.address


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "source": source,
            "companyName": company_name,
        })
        if domain is not UNSET:
            field_dict["domain"] = domain
        if context is not UNSET:
            field_dict["context"] = context
        if city is not UNSET:
            field_dict["city"] = city
        if state is not UNSET:
            field_dict["state"] = state
        if state_code is not UNSET:
            field_dict["stateCode"] = state_code
        if country_name is not UNSET:
            field_dict["countryName"] = country_name
        if country_3_letter_code is not UNSET:
            field_dict["country3LetterCode"] = country_3_letter_code
        if address is not UNSET:
            field_dict["address"] = address

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        source = StartLocalBusinessSearchBodyDataItemType0Source(d.pop("source"))




        company_name = d.pop("companyName")

        def _parse_domain(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        domain = _parse_domain(d.pop("domain", UNSET))


        def _parse_context(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        context = _parse_context(d.pop("context", UNSET))


        def _parse_city(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        city = _parse_city(d.pop("city", UNSET))


        def _parse_state(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        state = _parse_state(d.pop("state", UNSET))


        def _parse_state_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        state_code = _parse_state_code(d.pop("stateCode", UNSET))


        def _parse_country_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_name = _parse_country_name(d.pop("countryName", UNSET))


        def _parse_country_3_letter_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_3_letter_code = _parse_country_3_letter_code(d.pop("country3LetterCode", UNSET))


        def _parse_address(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        address = _parse_address(d.pop("address", UNSET))


        start_local_business_search_body_data_item_type_0 = cls(
            source=source,
            company_name=company_name,
            domain=domain,
            context=context,
            city=city,
            state=state,
            state_code=state_code,
            country_name=country_name,
            country_3_letter_code=country_3_letter_code,
            address=address,
        )


        start_local_business_search_body_data_item_type_0.additional_properties = d
        return start_local_business_search_body_data_item_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_none_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0Item
  from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item
  from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_any_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0Item





T = TypeVar("T", bound="SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0")



@_attrs_define
class SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0:
    """ 
        Attributes:
            obeys_all (Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item']]):
            obeys_any (Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0Item']]):
            obeys_none (Union[None, Unset,
                list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0Item']]):
     """

    obeys_all: Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item']] = UNSET
    obeys_any: Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0Item']] = UNSET
    obeys_none: Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0Item']] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_none_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0Item
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_any_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0Item
        obeys_all: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.obeys_all, Unset):
            obeys_all = UNSET
        elif isinstance(self.obeys_all, list):
            obeys_all = []
            for obeys_all_type_0_item_data in self.obeys_all:
                obeys_all_type_0_item = obeys_all_type_0_item_data.to_dict()
                obeys_all.append(obeys_all_type_0_item)


        else:
            obeys_all = self.obeys_all

        obeys_any: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.obeys_any, Unset):
            obeys_any = UNSET
        elif isinstance(self.obeys_any, list):
            obeys_any = []
            for obeys_any_type_0_item_data in self.obeys_any:
                obeys_any_type_0_item = obeys_any_type_0_item_data.to_dict()
                obeys_any.append(obeys_any_type_0_item)


        else:
            obeys_any = self.obeys_any

        obeys_none: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.obeys_none, Unset):
            obeys_none = UNSET
        elif isinstance(self.obeys_none, list):
            obeys_none = []
            for obeys_none_type_0_item_data in self.obeys_none:
                obeys_none_type_0_item = obeys_none_type_0_item_data.to_dict()
                obeys_none.append(obeys_none_type_0_item)


        else:
            obeys_none = self.obeys_none


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if obeys_all is not UNSET:
            field_dict["obeysAll"] = obeys_all
        if obeys_any is not UNSET:
            field_dict["obeysAny"] = obeys_any
        if obeys_none is not UNSET:
            field_dict["obeysNone"] = obeys_none

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_none_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0Item
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_any_type_0_item import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0Item
        d = dict(src_dict)
        def _parse_obeys_all(data: object) -> Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                obeys_all_type_0 = []
                _obeys_all_type_0 = data
                for obeys_all_type_0_item_data in (_obeys_all_type_0):
                    obeys_all_type_0_item = SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item.from_dict(obeys_all_type_0_item_data)



                    obeys_all_type_0.append(obeys_all_type_0_item)

                return obeys_all_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item']], data)

        obeys_all = _parse_obeys_all(d.pop("obeysAll", UNSET))


        def _parse_obeys_any(data: object) -> Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                obeys_any_type_0 = []
                _obeys_any_type_0 = data
                for obeys_any_type_0_item_data in (_obeys_any_type_0):
                    obeys_any_type_0_item = SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0Item.from_dict(obeys_any_type_0_item_data)



                    obeys_any_type_0.append(obeys_any_type_0_item)

                return obeys_any_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0Item']], data)

        obeys_any = _parse_obeys_any(d.pop("obeysAny", UNSET))


        def _parse_obeys_none(data: object) -> Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                obeys_none_type_0 = []
                _obeys_none_type_0 = data
                for obeys_none_type_0_item_data in (_obeys_none_type_0):
                    obeys_none_type_0_item = SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0Item.from_dict(obeys_none_type_0_item_data)



                    obeys_none_type_0.append(obeys_none_type_0_item)

                return obeys_none_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0Item']], data)

        obeys_none = _parse_obeys_none(d.pop("obeysNone", UNSET))


        sync_combined_search_body_company_params_employee_trends_type_0 = cls(
            obeys_all=obeys_all,
            obeys_any=obeys_any,
            obeys_none=obeys_none,
        )


        sync_combined_search_body_company_params_employee_trends_type_0.additional_properties = d
        return sync_combined_search_body_company_params_employee_trends_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import IntEnum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeeCountV2Type0UpperBoundInclusiveType4(IntEnum):
    VALUE_200 = 200

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="KitchenSinkBulkCompanyResponse200OutputDataItemItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0")



@_attrs_define
class KitchenSinkBulkCompanyResponse200OutputDataItemItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0:
    """ 
        Attributes:
            lat (float):
            lon (float):
     """

    lat: float
    lon: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        lat = self.lat

        lon = self.lon


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "lat": lat,
            "lon": lon,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        lat = d.pop("lat")

        lon = d.pop("lon")

        kitchen_sink_bulk_company_response_200_output_data_item_item_num_matching_locations_type_0_matched_offices_item_location_type_0_coordinates_type_0 = cls(
            lat=lat,
            lon=lon,
        )


        kitchen_sink_bulk_company_response_200_output_data_item_item_num_matching_locations_type_0_matched_offices_item_location_type_0_coordinates_type_0.additional_properties = d
        return kitchen_sink_bulk_company_response_200_output_data_item_item_num_matching_locations_type_0_matched_offices_item_location_type_0_coordinates_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class TextToCompanySearchResponse200OutputSearchParamsExactCompanyV2Type0AnyOfType0ItemType3Identifier(str, Enum):
    ADVANCED = "advanced"

    def __str__(self) -> str:
        return str(self.value)



from enum import IntEnum

class TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0UpperBoundInclusiveType3(IntEnum):
    VALUE_50 = 50

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsTechnologiesType0NoneOfType0ItemType0Technology(str, Enum):
    AIRFLOW = "Airflow"
    ALGOLIA = "Algolia"
    AMPLITUDE = "Amplitude"
    ANGULAR = "Angular"
    ANSIBLE = "Ansible"
    ANTHROPIC = "Anthropic"
    APACHE = "Apache"
    APACHE_SPARK = "Apache Spark"
    AWS = "AWS"
    AZURE = "Azure"
    AZURE_DEVOPS = "Azure DevOps"
    BIGQUERY = "BigQuery"
    BITBUCKET = "Bitbucket"
    BOOTSTRAP = "Bootstrap"
    C = "C++"
    CASSANDRA = "Cassandra"
    CIRCLECI = "CircleCI"
    CLICKHOUSE = "ClickHouse"
    CLOUDFLARE = "Cloudflare"
    CLOUDINARY = "Cloudinary"
    COCKROACHDB = "CockroachDB"
    CONFLUENCE = "Confluence"
    CONTENTFUL = "Contentful"
    CUDA = "CUDA"
    CURSOR = "Cursor"
    CYPRESS = "Cypress"
    DATABRICKS = "Databricks"
    DATADOG = "Datadog"
    DBT = "dbt"
    DJANGO = "Django"
    DOCKER = "Docker"
    DYNAMODB = "DynamoDB"
    ELASTICSEARCH = "Elasticsearch"
    ELIXIR = "Elixir"
    ELK_STACK = "ELK Stack"
    EXPRESS = "Express"
    FASTIFY = "Fastify"
    FIREBASE = "Firebase"
    FLASK = "Flask"
    FLY_IO = "Fly.io"
    GITHUB = "GitHub"
    GITLAB = "GitLab"
    GO = "Go"
    GOOGLE_ANALYTICS = "Google Analytics"
    GOOGLE_CLOUD = "Google Cloud"
    GRAFANA = "Grafana"
    GRAPHQL = "GraphQL"
    GUSTO = "Gusto"
    HADOOP = "Hadoop"
    HASURA = "Hasura"
    HELM = "Helm"
    HUBSPOT = "HubSpot"
    INFLUXDB = "InfluxDB"
    INTERCOM = "Intercom"
    JAVA = "Java"
    JAVASCRIPT = "JavaScript"
    JENKINS = "Jenkins"
    JIRA = "Jira"
    JUPYTER = "Jupyter"
    KAFKA = "Kafka"
    KERAS = "Keras"
    KLAVIYO = "Klaviyo"
    KOTLIN = "Kotlin"
    KUBEFLOW = "Kubeflow"
    KUBERNETES = "Kubernetes"
    LANGCHAIN = "LangChain"
    LARAVEL = "Laravel"
    LOOKER = "Looker"
    MAGENTO = "Magento"
    MARKETO = "Marketo"
    MICROSOFT_TEAMS = "Microsoft Teams"
    MIXPANEL = "Mixpanel"
    MONGODB = "MongoDB"
    MYSQL = "MySQL"
    NEO4J = "Neo4j"
    NESTJS = "NestJS"
    NETLIFY = "Netlify"
    NEW_RELIC = "New Relic"
    NEXT_JS = "Next.js"
    NGINX = "Nginx"
    NODE_JS = "Node.js"
    NOTION = "Notion"
    NUMPY = "NumPy"
    OPENAI = "OpenAI"
    OPENSEARCH = "OpenSearch"
    PAGERDUTY = "PagerDuty"
    PHP = "PHP"
    PLANETSCALE = "PlanetScale"
    PLAYWRIGHT = "Playwright"
    POSTGRESQL = "PostgreSQL"
    POWER_BI = "Power BI"
    PRISMA = "Prisma"
    PROMETHEUS = "Prometheus"
    PUPPETEER = "Puppeteer"
    PYTHON = "Python"
    PYTORCH = "PyTorch"
    RABBITMQ = "RabbitMQ"
    RAILWAY = "Railway"
    REACT = "React"
    REDIS = "Redis"
    REDSHIFT = "Redshift"
    RENDER = "Render"
    RIPPLING = "Rippling"
    RUBY = "Ruby"
    RUST = "Rust"
    SALESFORCE = "Salesforce"
    SCALA = "Scala"
    SCIKIT_LEARN = "Scikit-learn"
    SEGMENT = "Segment"
    SELENIUM = "Selenium"
    SENTRY = "Sentry"
    SERVICENOW = "ServiceNow"
    SHOPIFY = "Shopify"
    SLACK = "Slack"
    SNOWFLAKE = "Snowflake"
    SOLR = "Solr"
    SPLUNK = "Splunk"
    SPRING_BOOT = "Spring Boot"
    SQL = "SQL"
    SQLITE = "SQLite"
    STRIPE = "Stripe"
    SUPABASE = "Supabase"
    SWIFT = "Swift"
    TABLEAU = "Tableau"
    TAILWIND_CSS = "Tailwind CSS"
    TENSORFLOW = "TensorFlow"
    TERRAFORM = "Terraform"
    TIMESCALEDB = "TimescaleDB"
    TRAVIS_CI = "Travis CI"
    TWILIO = "Twilio"
    TYPESCRIPT = "TypeScript"
    VERCEL = "Vercel"
    VUE_JS = "Vue.js"
    WEBFLOW = "Webflow"
    WEIGHTS_BIASES = "Weights & Biases"
    WINDSURF = "Windsurf"
    WOOCOMMERCE = "WooCommerce"
    WORDPRESS = "WordPress"
    ZAPIER = "Zapier"
    ZENDESK = "Zendesk"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemSchoolV3Type0NoneOfType0ItemSourceType1(str, Enum):
    CSV = "csv"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0")



@_attrs_define
class TextToCompanySearchParamsResponse200OutputSearchParamsKeywordsType0:
    """ 
        Attributes:
            contains_all (Union[None, Unset, list[str]]):
            contains_any (Union[None, Unset, list[str]]):
            contains_none (Union[None, Unset, list[str]]):
     """

    contains_all: Union[None, Unset, list[str]] = UNSET
    contains_any: Union[None, Unset, list[str]] = UNSET
    contains_none: Union[None, Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        contains_all: Union[None, Unset, list[str]]
        if isinstance(self.contains_all, Unset):
            contains_all = UNSET
        elif isinstance(self.contains_all, list):
            contains_all = self.contains_all


        else:
            contains_all = self.contains_all

        contains_any: Union[None, Unset, list[str]]
        if isinstance(self.contains_any, Unset):
            contains_any = UNSET
        elif isinstance(self.contains_any, list):
            contains_any = self.contains_any


        else:
            contains_any = self.contains_any

        contains_none: Union[None, Unset, list[str]]
        if isinstance(self.contains_none, Unset):
            contains_none = UNSET
        elif isinstance(self.contains_none, list):
            contains_none = self.contains_none


        else:
            contains_none = self.contains_none


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if contains_all is not UNSET:
            field_dict["containsAll"] = contains_all
        if contains_any is not UNSET:
            field_dict["containsAny"] = contains_any
        if contains_none is not UNSET:
            field_dict["containsNone"] = contains_none

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_contains_all(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                contains_all_type_0 = cast(list[str], data)

                return contains_all_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        contains_all = _parse_contains_all(d.pop("containsAll", UNSET))


        def _parse_contains_any(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                contains_any_type_0 = cast(list[str], data)

                return contains_any_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        contains_any = _parse_contains_any(d.pop("containsAny", UNSET))


        def _parse_contains_none(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                contains_none_type_0 = cast(list[str], data)

                return contains_none_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        contains_none = _parse_contains_none(d.pop("containsNone", UNSET))


        text_to_company_search_params_response_200_output_search_params_keywords_type_0 = cls(
            contains_all=contains_all,
            contains_any=contains_any,
            contains_none=contains_none,
        )


        text_to_company_search_params_response_200_output_search_params_keywords_type_0.additional_properties = d
        return text_to_company_search_params_response_200_output_search_params_keywords_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.poll_combined_search_response_200_output_data_type_0_items_item_fortune_rankings_type_0_item_list import PollCombinedSearchResponse200OutputDataType0ItemsItemFortuneRankingsType0ItemList






T = TypeVar("T", bound="PollCombinedSearchResponse200OutputDataType0ItemsItemFortuneRankingsType0Item")



@_attrs_define
class PollCombinedSearchResponse200OutputDataType0ItemsItemFortuneRankingsType0Item:
    """ 
        Attributes:
            list_ (PollCombinedSearchResponse200OutputDataType0ItemsItemFortuneRankingsType0ItemList):
            year (float):
            rank (float):
     """

    list_: PollCombinedSearchResponse200OutputDataType0ItemsItemFortuneRankingsType0ItemList
    year: float
    rank: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        list_ = self.list_.value

        year = self.year

        rank = self.rank


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "list": list_,
            "year": year,
            "rank": rank,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        list_ = PollCombinedSearchResponse200OutputDataType0ItemsItemFortuneRankingsType0ItemList(d.pop("list"))




        year = d.pop("year")

        rank = d.pop("rank")

        poll_combined_search_response_200_output_data_type_0_items_item_fortune_rankings_type_0_item = cls(
            list_=list_,
            year=year,
            rank=rank,
        )


        poll_combined_search_response_200_output_data_type_0_items_item_fortune_rankings_type_0_item.additional_properties = d
        return poll_combined_search_response_200_output_data_type_0_items_item_fortune_rankings_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0VideoType0")



@_attrs_define
class CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0VideoType0:
    """ 
        Attributes:
            video_url (Union[None, Unset, str]):
            thumbnail_url (Union[None, Unset, str]):
     """

    video_url: Union[None, Unset, str] = UNSET
    thumbnail_url: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        video_url: Union[None, Unset, str]
        if isinstance(self.video_url, Unset):
            video_url = UNSET
        else:
            video_url = self.video_url

        thumbnail_url: Union[None, Unset, str]
        if isinstance(self.thumbnail_url, Unset):
            thumbnail_url = UNSET
        else:
            thumbnail_url = self.thumbnail_url


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if video_url is not UNSET:
            field_dict["videoUrl"] = video_url
        if thumbnail_url is not UNSET:
            field_dict["thumbnailUrl"] = thumbnail_url

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_video_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        video_url = _parse_video_url(d.pop("videoUrl", UNSET))


        def _parse_thumbnail_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        thumbnail_url = _parse_thumbnail_url(d.pop("thumbnailUrl", UNSET))


        company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_video_type_0 = cls(
            video_url=video_url,
            thumbnail_url=thumbnail_url,
        )


        company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_video_type_0.additional_properties = d
        return company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_video_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import Union

if TYPE_CHECKING:
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_not_applicable import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0NotApplicable
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_entry_level import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0EntryLevel
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_director import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Director
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_internship import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Internship
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_executive import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Executive
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_mid_senior_level import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0MidSeniorLevel
  from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_associate import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Associate





T = TypeVar("T", bound="KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0")



@_attrs_define
class KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0:
    """ 
        Attributes:
            entry_level (Union[Unset,
                KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0EntryLevel]):
            director (Union[Unset,
                KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Director]):
            associate (Union[Unset,
                KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Associate]):
            mid_senior_level (Union[Unset,
                KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0MidSeniorLevel]):
            internship (Union[Unset,
                KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Internship]):
            executive (Union[Unset,
                KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Executive]):
            not_applicable (Union[Unset,
                KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0NotApplicable]):
     """

    entry_level: Union[Unset, 'KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0EntryLevel'] = UNSET
    director: Union[Unset, 'KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Director'] = UNSET
    associate: Union[Unset, 'KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Associate'] = UNSET
    mid_senior_level: Union[Unset, 'KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0MidSeniorLevel'] = UNSET
    internship: Union[Unset, 'KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Internship'] = UNSET
    executive: Union[Unset, 'KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Executive'] = UNSET
    not_applicable: Union[Unset, 'KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0NotApplicable'] = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_not_applicable import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0NotApplicable
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_entry_level import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0EntryLevel
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_director import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Director
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_internship import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Internship
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_executive import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Executive
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_mid_senior_level import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0MidSeniorLevel
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_associate import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Associate
        entry_level: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entry_level, Unset):
            entry_level = self.entry_level.to_dict()

        director: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.director, Unset):
            director = self.director.to_dict()

        associate: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.associate, Unset):
            associate = self.associate.to_dict()

        mid_senior_level: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mid_senior_level, Unset):
            mid_senior_level = self.mid_senior_level.to_dict()

        internship: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.internship, Unset):
            internship = self.internship.to_dict()

        executive: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.executive, Unset):
            executive = self.executive.to_dict()

        not_applicable: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.not_applicable, Unset):
            not_applicable = self.not_applicable.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if entry_level is not UNSET:
            field_dict["Entry level"] = entry_level
        if director is not UNSET:
            field_dict["Director"] = director
        if associate is not UNSET:
            field_dict["Associate"] = associate
        if mid_senior_level is not UNSET:
            field_dict["Mid-Senior level"] = mid_senior_level
        if internship is not UNSET:
            field_dict["Internship"] = internship
        if executive is not UNSET:
            field_dict["Executive"] = executive
        if not_applicable is not UNSET:
            field_dict["Not Applicable"] = not_applicable

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_not_applicable import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0NotApplicable
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_entry_level import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0EntryLevel
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_director import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Director
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_internship import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Internship
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_executive import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Executive
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_mid_senior_level import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0MidSeniorLevel
        from ..models.kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0_associate import KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Associate
        d = dict(src_dict)
        _entry_level = d.pop("Entry level", UNSET)
        entry_level: Union[Unset, KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0EntryLevel]
        if isinstance(_entry_level,  Unset):
            entry_level = UNSET
        else:
            entry_level = KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0EntryLevel.from_dict(_entry_level)




        _director = d.pop("Director", UNSET)
        director: Union[Unset, KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Director]
        if isinstance(_director,  Unset):
            director = UNSET
        else:
            director = KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Director.from_dict(_director)




        _associate = d.pop("Associate", UNSET)
        associate: Union[Unset, KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Associate]
        if isinstance(_associate,  Unset):
            associate = UNSET
        else:
            associate = KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Associate.from_dict(_associate)




        _mid_senior_level = d.pop("Mid-Senior level", UNSET)
        mid_senior_level: Union[Unset, KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0MidSeniorLevel]
        if isinstance(_mid_senior_level,  Unset):
            mid_senior_level = UNSET
        else:
            mid_senior_level = KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0MidSeniorLevel.from_dict(_mid_senior_level)




        _internship = d.pop("Internship", UNSET)
        internship: Union[Unset, KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Internship]
        if isinstance(_internship,  Unset):
            internship = UNSET
        else:
            internship = KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Internship.from_dict(_internship)




        _executive = d.pop("Executive", UNSET)
        executive: Union[Unset, KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Executive]
        if isinstance(_executive,  Unset):
            executive = UNSET
        else:
            executive = KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0Executive.from_dict(_executive)




        _not_applicable = d.pop("Not Applicable", UNSET)
        not_applicable: Union[Unset, KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0NotApplicable]
        if isinstance(_not_applicable,  Unset):
            not_applicable = UNSET
        else:
            not_applicable = KitchenSinkBulkCompanyResponse200OutputDataItemItemLiJobPostsStatsType0SeniorityStatsType0NotApplicable.from_dict(_not_applicable)




        kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0 = cls(
            entry_level=entry_level,
            director=director,
            associate=associate,
            mid_senior_level=mid_senior_level,
            internship=internship,
            executive=executive,
            not_applicable=not_applicable,
        )

        return kitchen_sink_bulk_company_response_200_output_data_item_item_li_job_posts_stats_type_0_seniority_stats_type_0

